/**
  ******************************************************************************
  * @file    main.c
  * @author  MCD Application Team
  * @version V1.0.0
  * @date    31-October-2011
  * @brief   Main program body
  ******************************************************************************
  * @attention
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2011 STMicroelectronics</center></h2>
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/

#include <stdio.h>
#include "main.h"
#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"
#include "semphr.h"
#include "can_example.h"

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/

/*--------------- Tasks Priority -------------*/
#define REG_TASK_PRIO   ( tskIDLE_PRIORITY + 1 )


/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/


CanRxMsg Message;

GPIO_InitTypeDef GPIO_InitStructure;

/* Private function prototypes -----------------------------------------------*/
void LED_Init(void);
uint8_t CAN_Send(CAN_TypeDef* CANx,CanTxMsg *Message);

/* Private functions ---------------------------------------------------------*/
/**
  * @brief  CAN1 sends Message and toggles LED orange
  * @param  pvParameters not used
  * @retval None
  */

/**
  * @brief  Get received Message and toggles LED
  * @param  pvParameters not used
  * @retval None
  */
void vTask_Reg ( void * pvParameters )
{
	volatile uint32_t important_var;
	static uint16_t i;
	static portTickType xLastWakeTime;

	xLastWakeTime = xTaskGetTickCount();

    for(;;)
    {

    	for(i=0;i<50000;i++)
    	{
    		important_var++;
    	}

    	GPIO_ResetBits(GPIOE, GPIO_Pin_9);

    	 vTaskDelayUntil( &xLastWakeTime, 10 );

    	GPIO_SetBits(GPIOE, GPIO_Pin_9);
    }

}
/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
int main(void)
{
	CanRxMsg RxMessage;
	int8_t err;

	SystemInit();

  /*!< At this stage the microcontroller clock setting is already configured to
       168 MHz, this is done through SystemInit() function which is called from
       startup file (startup_stm32f4xx.s) before to branch to application main.
       To reconfigure the default setting of SystemInit() function, refer to
       system_stm32f4xx.c file
     */

  /*Initialize Leds */
  LED_Init();

  /*Configure the Interrupt*/
  InterruptCAN_Init();

  CAN_Initialisierung();


  /* Create Tasks */
  xTaskCreate( vTask_Reg, NULL, configMINIMAL_STACK_SIZE, NULL, REG_TASK_PRIO, NULL);

 /*Enable CAN Interrupt*/
  CAN_ITConfig(CAN2, CAN_IT_FMP0, ENABLE);
 /*Enable CAN Interrupt*/
  CAN_ITConfig(CAN1, CAN_IT_FMP1, ENABLE);

  /* Start scheduler */
  vTaskStartScheduler();

  /* We should never get here as control is now taken by the scheduler */
  for( ;; );
}



/**
  * @brief  Initializes the LEDs resources.
  * @param  None
  * @retval None
  */
void LED_Init(void)
{
#ifdef USE_LCD
  /* Initialize the STM324xG-EVAL's LCD */
  STM324xG_LCD_Init();
#endif

  /* Initialize Discovery's LEDs */
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOD, ENABLE);

  /* Configure PD15 in output pushpull mode */
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_12|GPIO_Pin_13|  GPIO_Pin_14|  GPIO_Pin_15;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
  GPIO_Init(GPIOD, &GPIO_InitStructure);


}



/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
